==> react-7.4.1.tgz: package/es/ListItem/index.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _inheritsLoose(subClass, superClass) { subClass.prototype.__proto__ = superClass && superClass.prototype; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

import React from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';
import { uniqueId } from 'lodash';
/**
 * @category containers
 * @component list-item
 * @variations collab-ui-react
 */

var ListItem =
/*#__PURE__*/
function (_React$Component) {
  function ListItem() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      id: uniqueId(_this.props.id && _this.props.id + "-" || 'cui-list-item-')
    }, _this.checkElements = function (tag) {
      var children = Object.values(ReactDOM.findDOMNode(_assertThisInitialized(_assertThisInitialized(_this))).childNodes);
      return _this.countDOMChildren(children, tag);
    }, _this.countDOMChildren = function (children, tag) {
      return children.reduce(function (agg, child) {
        return child.tagName === tag ? _objectSpread({}, agg, {
          count: agg.count += 1
        }) : agg;
      }, {
        count: 0,
        children: children.length
      });
    }, _this.getChildrenElements = function (name) {
      var children = _this.props.children;
      var elementCount = 0;
      var childrenLength = 0;
      React.Children.forEach(children, function (child) {
        childrenLength++;

        if (child.type && child.type.displayName === name) {
          return elementCount++;
        }
      });
      return elementCount && {
        isCorrectUsage: elementCount === childrenLength,
        length: elementCount
      };
    }, _this.handleClick = function (e) {
      var _this$props = _this.props,
          disabled = _this$props.disabled,
          itemIndex = _this$props.itemIndex,
          onClick = _this$props.onClick,
          value = _this$props.value;
      var setSelected = _this.context.setSelected;

      if (disabled) {
        e.preventDefault();
        e.stopPropagation();
      }

      setSelected(e, itemIndex, value);
      onClick && onClick(e);
    }, _this.handleKeyDown = function (e) {
      var _this$props2 = _this.props,
          disabled = _this$props2.disabled,
          itemIndex = _this$props2.itemIndex,
          onKeyDown = _this$props2.onKeyDown;
      var handleListKeyDown = _this.context.handleListKeyDown;

      if (disabled) {
        e.preventDefault();
        e.stopPropagation();
      }

      handleListKeyDown(e, itemIndex);
      onKeyDown && onKeyDown(e);
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = ListItem.prototype;

  _proto.componentWillMount = function componentWillMount() {
    if (!this.props.children) return;
    var checkChildren = this.getChildrenElements('ListItemSection');

    if (!checkChildren) {
      return;
    } else if (!checkChildren.isCorrectUsage) {
      throw new Error("If ListItemSection Component is used all children must use ListItemSection Components.");
    } else if (checkChildren.length > 3) {
      throw new Error("Only 3 ListItemSection components can be used as children. You've used " + checkChildren.length);
    }
  };

  _proto.componentDidMount = function componentDidMount() {
    var anchorCount = this.checkElements('A');

    if (anchorCount.count > 1) {
      throw new Error('Only 1 primary child anchor tag may be used with ListItem component');
    } else if (anchorCount.count === 1 && anchorCount.children > 1) {
      throw new Error('Anchor tag can not have sibling');
    }
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    var _this$props3 = this.props,
        focus = _this$props3.focus,
        refName = _this$props3.refName;
    prevProps.focus !== focus && focus && this[refName] && this[refName].focus();
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props4 = this.props,
        className = _this$props4.className,
        customAnchorNode = _this$props4.customAnchorNode,
        focus = _this$props4.focus,
        role = _this$props4.role,
        refName = _this$props4.refName,
        link = _this$props4.link,
        children = _this$props4.children,
        type = _this$props4.type,
        customRefProp = _this$props4.customRefProp,
        label = _this$props4.label,
        active = _this$props4.active,
        disabled = _this$props4.disabled;
    var id = this.state.id;

    var addRefToAnchor = function addRefToAnchor(node) {
      var _ref;

      return React.cloneElement(node, _objectSpread({
        'aria-current': focus,
        tabIndex: !disabled && focus ? 0 : -1,
        onClick: _this2.handleClick,
        onKeyDown: _this2.handleKeyDown,
        role: role,
        className: 'cui-list-item' + ("" + (type && " cui-list-item--" + type || '')) + ("" + (active && " active" || '')) + ("" + (disabled && " disabled" || '')) + ("" + (className && " " + className || '')) + ("" + (node.props.className && " " + node.props.className || ''))
      }, customRefProp && (_ref = {}, _ref[customRefProp] = function (ref) {
        return _this2[_this2.props.refName] = ref;
      }, _ref)), children || node.props.children || label);
    };

    var customProps = {
      className: 'cui-list-item' + ("" + (type && " cui-list-item--" + type || '')) + ("" + (active && " active" || '')) + ("" + (disabled && " disabled" || '')) + ("" + (className && " " + className || '')),
      role: role,
      ref: function ref(_ref2) {
        return _this2[refName] = _ref2;
      },
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      tabIndex: focus && !disabled ? 0 : -1,
      'aria-current': focus,
      id: id
    };
    return customAnchorNode ? addRefToAnchor(customAnchorNode) : React.createElement(link ? 'a' : 'div', _objectSpread({}, customProps, link && {
      href: link
    }), children || label);
  };

  _inheritsLoose(ListItem, _React$Component);

  return ListItem;
}(React.Component);

ListItem.displayName = 'ListItem';
ListItem.contextTypes = {
  setSelected: PropTypes.func,
  handleListKeyDown: PropTypes.func
};
ListItem.defaultProps = {
  customAnchorNode: null,
  children: null,
  className: '',
  customRefProp: '',
  focus: false,
  id: null,
  itemIndex: null,
  label: '',
  link: '',
  onClick: null,
  onKeyDown: null,
  refName: 'navLink',
  role: 'listItem',
  type: '',
  active: false,
  disabled: false,
  value: ''
};
ListItem.propTypes = {
  /** Class Name for Nav Link */
  customAnchorNode: PropTypes.element,

  /** children prop */
  children: PropTypes.node,

  /** HTML Class for associated input */
  className: PropTypes.string,

  /** ListItem Custom Prop Name for child with custom Ref */
  customRefProp: PropTypes.string,

  /** Focus prop to help determine styles */
  focus: PropTypes.bool,

  /** Active prop to help determine styles */
  active: PropTypes.bool,

  /** Disabled prop to help determine styles */
  disabled: PropTypes.bool,

  /** ListItem id */
  id: PropTypes.string,

  /** ListItem number */
  itemIndex: PropTypes.number,

  /** ListItem text */
  label: PropTypes.string,

  /** external link associated input */
  link: PropTypes.string,

  /** onClick function */
  onClick: PropTypes.func,

  /** onKeyDown function */
  onKeyDown: PropTypes.func,

  /** ListItem ref name */
  refName: PropTypes.string,

  /** aria role */
  role: PropTypes.string,

  /** ListItem Type */
  type: PropTypes.oneOf(['', 'small', 'large', 'xlarge', 'space', 'header']),

  /** ListItem Value for OnSelect Value */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number, PropTypes.object, PropTypes.array])
};
export default ListItem;
/**
* @name Default
*
* @category containers
* @component list-item
* @section default
*
* @js
*
import { List } from '@collab-ui/react';

export default class ListItemDefault extends React.PureComponent {

  render() {
    return(
      <div className="medium-4 columns">
        <List>
          <ListItem label='Default List Item 1' />
          <ListItem label='Default List Item 2' />
        </List>
      </div>
    );
  }
}
**/

/**
* @name Type
*
* @category containers
* @component list-item
* @section type
*
* @js
*
import { List } from '@collab-ui/react';

export default class ListItemType extends React.PureComponent {

  render() {
    return(
      <div className="medium-4 columns">
        <List>
          <ListItem type='small' link='javascript:void(0)' label='Small List Item' />
          <ListItem link='javascript:void(0)' label='Regular List Item' />
          <ListItem type='large' link='javascript:void(0)' label='Large List Item' />
          <ListItem type='xlarge' link='javascript:void(0)' label='XLarge List Item' />
        </List>
      </div>
    );
  }
}
**/

/**
* @name List Item Sections
*
* @category containers
* @component list-item
* @section list-item-sections
*
* @js
*
import { List, ListItemSection } from '@collab-ui/react';

export default class ListItemSectionExample extends React.PureComponent {

  render() {
    return(
      <div className="medium-4 columns">
        <List>
          <ListItem link='javascript:void(0)'>
            <ListItemSection position='left'>
              Left
              </ListItemSection>
              <ListItemSection position='right'>
                Right
              </ListItemSection>
          </ListItem>
          <ListItem link='javascript:void(0)'>
            <ListItemSection position='center'>
              Center
            </ListItemSection>
          </ListItem>
          <ListItem link='javascript:void(0)'>
            <ListItemSection position='center-align'>
              Center Align
            </ListItemSection>
          </ListItem>
          <ListItem link='javascript:void(0)'>
            <ListItemSection position='left'>
              Left
            </ListItemSection>
            <ListItemSection position='center'>
              Center
            </ListItemSection>
            <ListItemSection position='right'>
              Right
            </ListItemSection>
          </ListItem>
        </List>
      </div>
    );
  }
}
**/

/**
* @name Custom Link
*
* @category containers
* @component list-item
* @section custom-anchor
*
* @js
*
import { List } from '@collab-ui/react';
import { NavLink } from 'react-router-dom';

export default class CustomLinkExample extends React.PureComponent {

  render() {
    const anchorNode = <NavLink to='/containers/list-item' />;
    return(
      <div className="medium-4 columns">
        <List>
          <ListItem label='Custom Anchor' customRefProp='innerRef' customAnchorNode={anchorNode}/>
        </List>
      </div>
    );
  }
}
**/

==> react-7.6.0.tgz: package/es/ListItem/index.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

import React from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';
import { uniqueId } from 'lodash';
/**
 * @category containers
 * @component list-item
 * @variations collab-ui-react
 */

var ListItem =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(ListItem, _React$Component);

  function ListItem() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      id: uniqueId(_this.props.id && _this.props.id + "-" || 'cui-list-item-')
    }, _this.checkElements = function (tag) {
      var children = Object.values(ReactDOM.findDOMNode(_assertThisInitialized(_assertThisInitialized(_this))).childNodes);
      return _this.countDOMChildren(children, tag);
    }, _this.countDOMChildren = function (children, tag) {
      return children.reduce(function (agg, child) {
        return child.tagName === tag ? _objectSpread({}, agg, {
          count: agg.count += 1
        }) : agg;
      }, {
        count: 0,
        children: children.length
      });
    }, _this.getChildrenElements = function (name) {
      var children = _this.props.children;
      var elementCount = 0;
      var childrenLength = 0;
      React.Children.forEach(children, function (child) {
        childrenLength++;

        if (child.type && child.type.displayName === name) {
          return elementCount++;
        }
      });
      return elementCount && {
        isCorrectUsage: elementCount === childrenLength,
        length: elementCount
      };
    }, _this.handleClick = function (e) {
      var _this$props = _this.props,
          disabled = _this$props.disabled,
          itemIndex = _this$props.itemIndex,
          onClick = _this$props.onClick,
          value = _this$props.value;
      var setSelected = _this.context.setSelected;

      if (disabled) {
        e.preventDefault();
        e.stopPropagation();
      }

      setSelected && setSelected(e, itemIndex, value);
      onClick && onClick(e);
    }, _this.handleKeyDown = function (e) {
      var _this$props2 = _this.props,
          disabled = _this$props2.disabled,
          itemIndex = _this$props2.itemIndex,
          onKeyDown = _this$props2.onKeyDown;
      var handleListKeyDown = _this.context.handleListKeyDown;

      if (disabled) {
        e.preventDefault();
        e.stopPropagation();
      }

      handleListKeyDown && handleListKeyDown(e, itemIndex);
      onKeyDown && onKeyDown(e);
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = ListItem.prototype;

  _proto.componentWillMount = function componentWillMount() {
    if (!this.props.children) return;
    var checkChildren = this.getChildrenElements('ListItemSection');

    if (!checkChildren) {
      return;
    } else if (!checkChildren.isCorrectUsage) {
      throw new Error("If ListItemSection Component is used all children must use ListItemSection Components.");
    } else if (checkChildren.length > 3) {
      throw new Error("Only 3 ListItemSection components can be used as children. You've used " + checkChildren.length);
    }
  };

  _proto.componentDidMount = function componentDidMount() {
    var anchorCount = this.checkElements('A');
    var _this$props3 = this.props,
        focus = _this$props3.focus,
        refName = _this$props3.refName,
        focusOnLoad = _this$props3.focusOnLoad;

    if (anchorCount.count > 1) {
      throw new Error('Only 1 primary child anchor tag may be used with ListItem component');
    } else if (anchorCount.count === 1 && anchorCount.children > 1) {
      throw new Error('Anchor tag can not have sibling');
    }

    focusOnLoad && focus && this[refName] && this[refName].focus();
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    var _this$props4 = this.props,
        focus = _this$props4.focus,
        refName = _this$props4.refName;
    prevProps.focus !== focus && focus && this[refName] && this[refName].focus();
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props5 = this.props,
        className = _this$props5.className,
        customAnchorNode = _this$props5.customAnchorNode,
        focus = _this$props5.focus,
        role = _this$props5.role,
        refName = _this$props5.refName,
        link = _this$props5.link,
        children = _this$props5.children,
        type = _this$props5.type,
        customRefProp = _this$props5.customRefProp,
        label = _this$props5.label,
        active = _this$props5.active,
        disabled = _this$props5.disabled,
        isReadOnly = _this$props5.isReadOnly,
        separator = _this$props5.separator;
    var id = this.state.id;

    var addRefToAnchor = function addRefToAnchor(node) {
      var _ref;

      return React.cloneElement(node, _objectSpread({
        'aria-current': focus,
        tabIndex: !disabled && !isReadOnly && focus ? 0 : -1,
        onClick: _this2.handleClick,
        onKeyDown: _this2.handleKeyDown,
        role: role,
        className: 'cui-list-item' + ("" + (type && " cui-list-item--" + type || '')) + ("" + (active && " active" || '')) + ("" + (disabled && " disabled" || '')) + ("" + (isReadOnly && " cui-list-item--read-only" || '')) + ("" + (separator && " cui-list-item--separator" || '')) + ("" + (className && " " + className || '')) + ("" + (node.props.className && " " + node.props.className || ''))
      }, customRefProp && (_ref = {}, _ref[customRefProp] = function (ref) {
        return _this2[_this2.props.refName] = ref;
      }, _ref)), children || node.props.children || label);
    };

    var customProps = {
      className: 'cui-list-item' + ("" + (type && " cui-list-item--" + type || '')) + ("" + (active && " active" || '')) + ("" + (disabled && " disabled" || '')) + ("" + (isReadOnly && " cui-list-item--read-only" || '')) + ("" + (separator && " cui-list-item--separator" || '')) + ("" + (className && " " + className || '')),
      role: role,
      ref: function ref(_ref2) {
        return _this2[refName] = _ref2;
      },
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      tabIndex: focus && !disabled && !isReadOnly ? 0 : -1,
      'aria-current': focus,
      id: id
    };
    return customAnchorNode ? addRefToAnchor(customAnchorNode) : React.createElement(link ? 'a' : 'div', _objectSpread({}, customProps, link && {
      href: link
    }), children || label);
  };

  return ListItem;
}(React.Component);

ListItem.displayName = 'ListItem';
ListItem.contextTypes = {
  setSelected: PropTypes.func,
  handleListKeyDown: PropTypes.func
};
ListItem.defaultProps = {
  customAnchorNode: null,
  children: null,
  className: '',
  customRefProp: '',
  focus: false,
  id: null,
  itemIndex: null,
  label: '',
  link: '',
  onClick: null,
  onKeyDown: null,
  refName: 'navLink',
  role: 'listItem',
  type: '',
  active: false,
  disabled: false,
  value: '',
  isReadOnly: false,
  separator: false,
  focusOnLoad: false
};
ListItem.propTypes = {
  /** Class Name for Nav Link */
  customAnchorNode: PropTypes.element,

  /** children prop */
  children: PropTypes.node,

  /** HTML Class for associated input */
  className: PropTypes.string,

  /** ListItem Custom Prop Name for child with custom Ref */
  customRefProp: PropTypes.string,

  /** Focus prop to help determine styles */
  focus: PropTypes.bool,

  /** Active prop to help determine styles */
  active: PropTypes.bool,

  /** Disabled prop to help determine styles */
  disabled: PropTypes.bool,

  /** ListItem id */
  id: PropTypes.string,

  /** ListItem number */
  itemIndex: PropTypes.number,

  /** ListItem text */
  label: PropTypes.string,

  /** external link associated input */
  link: PropTypes.string,

  /** onClick function */
  onClick: PropTypes.func,

  /** onKeyDown function */
  onKeyDown: PropTypes.func,

  /** ListItem ref name */
  refName: PropTypes.string,

  /** aria role */
  role: PropTypes.string,

  /** ListItem Type */
  type: PropTypes.oneOf(['', 'small', 'large', 'xlarge', 'space', 'header']),

  /** ListItem Value for OnSelect Value */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number, PropTypes.object, PropTypes.array]),
  isReadOnly: PropTypes.bool,

  /** prop that controls whether to show separator or not */
  separator: PropTypes.bool,
  focusOnLoad: PropTypes.bool
};
export default ListItem;
/**
* @name Default
*
* @category containers
* @component list-item
* @section default
*
* @js
*
import { List } from '@collab-ui/react';

export default class ListItemDefault extends React.PureComponent {

  render() {
    return(
      <div className="medium-4 columns">
        <List>
          <ListItem label='Default List Item 1' />
          <ListItem label='Default List Item 2' />
        </List>
      </div>
    );
  }
}
**/

/**
* @name Type
*
* @category containers
* @component list-item
* @section type
*
* @js
*
import { List } from '@collab-ui/react';

export default class ListItemType extends React.PureComponent {

  render() {
    return(
      <div className="medium-4 columns">
        <List>
          <ListItem type='small' link='javascript:void(0)' label='Small List Item' />
          <ListItem link='javascript:void(0)' label='Regular List Item' />
          <ListItem type='large' link='javascript:void(0)' label='Large List Item' />
          <ListItem type='xlarge' link='javascript:void(0)' label='XLarge List Item' />
        </List>
      </div>
    );
  }
}
**/

/**
* @name List Item Sections
*
* @category containers
* @component list-item
* @section list-item-sections
*
* @js
*
import { List, ListItemSection } from '@collab-ui/react';

export default class ListItemSectionExample extends React.PureComponent {

  render() {
    return(
      <div className="medium-4 columns">
        <List>
          <ListItem link='javascript:void(0)'>
            <ListItemSection position='left'>
              Left
              </ListItemSection>
              <ListItemSection position='right'>
                Right
              </ListItemSection>
          </ListItem>
          <ListItem link='javascript:void(0)'>
            <ListItemSection position='center'>
              Center
            </ListItemSection>
          </ListItem>
          <ListItem link='javascript:void(0)'>
            <ListItemSection position='center-align'>
              Center Align
            </ListItemSection>
          </ListItem>
          <ListItem link='javascript:void(0)'>
            <ListItemSection position='left'>
              Left
            </ListItemSection>
            <ListItemSection position='center'>
              Center
            </ListItemSection>
            <ListItemSection position='right'>
              Right
            </ListItemSection>
          </ListItem>
        </List>
      </div>
    );
  }
}
**/

/**
* @name Custom Link
*
* @category containers
* @component list-item
* @section custom-anchor
*
* @js
*
import { List } from '@collab-ui/react';
import { NavLink } from 'react-router-dom';

export default class CustomLinkExample extends React.PureComponent {

  render() {
    const anchorNode = <NavLink to='/containers/list-item' />;
    return(
      <div className="medium-4 columns">
        <List>
          <ListItem label='Custom Anchor' customRefProp='innerRef' customAnchorNode={anchorNode}/>
        </List>
      </div>
    );
  }
}
**/
